==> vokoscreen_2.0.5~beta.orig.tar.gz: vokoscreen-2.0.5-beta/language/vokoscreen_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mail seneste video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mail en eller flere af de valgte videoer</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Send</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Du finder videoen som en vedhæftet fil.</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Vælg en eller flere filer</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Ingen ramme</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Ramme</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Enheden er optaget</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Hele skærmen</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lup</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Optag ikke musemarkør</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosti</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Afspiller</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen bliver minimeret når optagelsen starter</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Send</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Optagetid</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Størrelse i KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Optager skærmstørrelse</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Indstillinger fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Åben mappe</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedtælling</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Afspil seneste video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Send video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuelle billeder pr. sekund</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Device % 1 er optaget</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/language/vokoscreen_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mail seneste video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mail en eller flere af de valgte videoer</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Send</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Du finder videoen som en vedhæftet fil.</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Vælg en eller flere filer</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>is busy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation>Ingen ramme</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Ramme</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Hele skærmen</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lup</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Optag ikke musemarkør</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosti</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Afspiller</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen bliver minimeret når optagelsen starter</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Send</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Optagetid</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Størrelse i KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Optager skærmstørrelse</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Indstillinger fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Åben mappe</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedtælling</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Afspil seneste video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Send video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuelle billeder pr. sekund</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Device % 1 er optaget</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
